@@ -1,5 +1,5 @@
 from pollination.ladybug_comfort.map import PmvMap, AdaptiveMap, UtciMap, \
-    MapResultInfo, Tcp
+    ShortwaveMrtMap, LongwaveMrtMap, AirMap, MapResultInfo, Tcp
 from queenbee.plugin.function import Function
 
 
@@ -21,6 +21,24 @@ def test_utci_map():
     assert isinstance(function, Function)
 
 
+def test_shortwave_mrt_map():
+    function = ShortwaveMrtMap().queenbee
+    assert function.name == 'shortwave-mrt-map'
+    assert isinstance(function, Function)
+
+
+def test_longwave_mrt_map():
+    function = LongwaveMrtMap().queenbee
+    assert function.name == 'longwave-mrt-map'
+    assert isinstance(function, Function)
+
+
+def test_air_map():
+    function = AirMap().queenbee
+    assert function.name == 'air-map'
+    assert isinstance(function, Function)
+
+
 def test_map_result_info():
     function = MapResultInfo().queenbee
     assert function.name == 'map-result-info'
